@@ -1,4 +1,4 @@
-/* $Id: sm_mem.c,v 1.4 2005/03/20 16:17:22 dijkstra Exp $ */
+/* $Id: sm_mem.c,v 1.8 2005/10/18 19:58:06 dijkstra Exp $ */
 
 /*
  * Copyright (c) 2004      Matthew Gream
@@ -34,8 +34,6 @@
  * Get current memory statistics in bytes; reports them back in symon_buf as
  *
  * real active : real total : free : [swap used : swap total]
- *
- * This code is not re-entrant.
  */
 
 #include "conf.h"
@@ -75,9 +73,8 @@ static long me_stats[5];
 static struct vmtotal me_vmtotal;
 static size_t me_vmsize = sizeof(struct vmtotal);
 
-/* Prepare mem module for first use */
 void
-init_mem(char *s)
+init_mem(struct stream *st)
 {
     me_pagesize = sysconf(_SC_PAGESIZE);
     me_pageshift = 0;
@@ -98,11 +95,17 @@ init_mem(char *s)
 	me_vmiswp_mib_len = 0;
     }
 
-    info("started module mem(%.200s)", s);
+    info("started module mem(%.200s)", st->arg);
 }
-/* Get memory statistics */
+
+void
+gets_mem()
+{
+    /* EMPTY */
+}
+
 int
-get_mem(char *symon_buf, int maxlen, char *s)
+get_mem(char *symon_buf, int maxlen, struct stream *st)
 {
 #ifdef HAS_XSWDEV
     int i;
@@ -118,6 +121,7 @@ get_mem(char *symon_buf, int maxlen, char *s)
     me_stats[0] = pagetob(me_vmtotal.t_arm);
     me_stats[1] = pagetob(me_vmtotal.t_rm);
     me_stats[2] = pagetob(me_vmtotal.t_free);
+    me_stats[3] = me_stats[4] = 0;
 
 #ifdef HAS_XSWDEV
     vmnswp_siz = sizeof (int);
@@ -134,11 +138,9 @@ get_mem(char *symon_buf, int maxlen, char *s)
 	me_stats[3] += (vmiswp_dat.xsw_used * DEV_BSIZE);
 	me_stats[4] += (vmiswp_dat.xsw_nblks * DEV_BSIZE);
     }
-#else
-    me_stats[3] = me_stats[4] = 0;
 #endif
 
-    return snpack(symon_buf, maxlen, s, MT_MEM,
+    return snpack(symon_buf, maxlen, st->arg, MT_MEM,
 		  me_stats[0], me_stats[1], me_stats[2],
 		  me_stats[3], me_stats[4]);
 }
