@@ -1,4 +1,4 @@
-/* $Id: sm_proc.c,v 1.4 2005/03/20 16:17:22 dijkstra Exp $ */
+/* $Id: sm_proc.c,v 1.7 2005/10/18 19:58:06 dijkstra Exp $ */
 
 /*
  * Copyright (c) 2004      Matthew Gream
@@ -35,8 +35,6 @@
  *
  * number of processes : ticks_user : ticks_system : ticks_interrupt :
  * cpuseconds : procsizes : resident segment sizes
- *
- * Non re-entrant code: gets_proc messes with globals r/w without a semaphore.
  */
 
 #include "conf.h"
@@ -121,20 +119,31 @@ gets_proc()
 	proc_cur = size / sizeof(struct kinfo_proc);
     }
 }
-/* Prepare io module for first use */
+
 void
-init_proc(char *s)
+privinit_proc()
+{
+#ifdef HAS_KI_PADDR
+    char errbuf[_POSIX2_LINE_MAX];
+
+    proc_kd = kvm_openfiles(NULL, NULL, NULL, O_RDONLY, errbuf);
+    if (proc_kd == NULL) {
+	warning("while opening kvm (chrooted?): %s", errbuf);
+    }
+#endif
+}
+
+void
+init_proc(struct stream *st)
 {
     int mib[2] = {CTL_KERN, KERN_CLOCKRATE};
     struct clockinfo cinf;
     size_t size = sizeof(cinf);
-#ifdef HAS_KI_PADDR
-    char errbuf[_POSIX2_LINE_MAX];
-#endif
 
     /* get clockrate */
-    if (sysctl(mib, 2, &cinf, &size, NULL, 0) == -1)
+    if (sysctl(mib, 2, &cinf, &size, NULL, 0) == -1) {
 	fatal("%s:%d: could not get clockrate", __FILE__, __LINE__);
+    }
 
     proc_stathz = cinf.stathz;
 
@@ -146,17 +155,11 @@ init_proc(char *s)
 	proc_pagesize >>= 1;
     }
 
-#ifdef HAS_KI_PADDR
-    proc_kd = kvm_openfiles(NULL, NULL, NULL, O_RDONLY, errbuf);
-    if (proc_kd == NULL)
-      warning("while opening kvm (chrooted?): %s", errbuf);
-#endif
-
-    info("started module proc(%.200s)", s);
+    info("started module proc(%.200s)", st->arg);
 }
-/* Get new io statistics */
+
 int
-get_proc(char *symon_buf, int maxlen, char *process)
+get_proc(char *symon_buf, int maxlen, struct stream *st)
 {
     int i;
     struct kinfo_proc *pp;
@@ -176,15 +179,15 @@ get_proc(char *symon_buf, int maxlen, char *process)
 
     for (pp = proc_ps, i = 0; i < proc_cur; pp++, i++) {
 #ifdef HAS_KI_PADDR
-	if (strncmp(process, pp->ki_comm, strlen(process)) == 0) {
+	if (strncmp(st->arg, pp->ki_comm, strlen(st->arg)) == 0) {
 	    /* cpu time - accumulated */
 	    if (proc_kd) {
 		if (kvm_read(proc_kd, (unsigned long)pp->ki_paddr, &pproc,
 			     sizeof(pproc)) == sizeof(pproc)) {
 #ifdef HAS_RUSAGE_EXT
-		    cpu_uticks += pproc.p_rux.p_uticks;  /* user */
-		    cpu_sticks += pproc.p_rux.p_sticks;  /* sys  */
-		    cpu_iticks += pproc.p_rux.p_iticks;  /* int  */
+		    cpu_uticks += pproc.p_rux.rux_uticks;  /* user */
+		    cpu_sticks += pproc.p_rux.rux_sticks;  /* sys  */
+		    cpu_iticks += pproc.p_rux.rux_iticks;  /* int  */
 #else
 		    cpu_uticks += pproc.p_uticks;  /* user */
 		    cpu_sticks += pproc.p_sticks;  /* sys  */
@@ -203,7 +206,7 @@ get_proc(char *symon_buf, int maxlen, char *process)
 				    pp->ki_ssize); /* stack */
 	    mem_rss += pagetob(pp->ki_rssize);     /* rss  */
 #else
-	if (strncmp(process, pp->kp_proc.p_comm, strlen(process)) == 0) {
+	if (strncmp(st->arg, pp->kp_proc.p_comm, strlen(st->arg)) == 0) {
 	    /* cpu time - accumulated */
 	    cpu_uticks += pp->kp_proc.p_uticks;  /* user */
 	    cpu_sticks += pp->kp_proc.p_sticks;  /* sys  */
@@ -226,7 +229,7 @@ get_proc(char *symon_buf, int maxlen, char *process)
     cpu_ticks = cpu_uticks + cpu_sticks + cpu_iticks;
     cpu_secs = cpu_ticks / proc_stathz;
 
-    return snpack(symon_buf, maxlen, process, MT_PROC,
+    return snpack(symon_buf, maxlen, st->arg, MT_PROC,
 		  n,
 		  cpu_uticks, cpu_sticks, cpu_iticks, cpu_secs, cpu_pcti,
 		  mem_procsize, mem_rss );
