@@ -1,8 +1,8 @@
-/* $Id: sm_debug.c,v 1.2 2005/02/04 09:49:26 dijkstra Exp $ */
+/* $Id: sm_debug.c,v 1.4 2005/10/18 19:58:09 dijkstra Exp $ */
 
 /*
  * Copyright (c) 2004      Matthew Gream
- * Copyright (c) 2001-2004 Willem Dijkstra
+ * Copyright (c) 2001-2005 Willem Dijkstra
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -35,7 +35,6 @@
  * Get current debug statistics from kernel and return them in symon_buf as
  *
  * debug0 : debug1 : ... : debug19
- *
  */
 
 #include <sys/param.h>
@@ -43,23 +42,22 @@
 
 #include <string.h>
 
+#include "conf.h"
 #include "error.h"
 #include "symon.h"
 
-#define SYMON_MAXDEBUGID      20 /* = CTL_DEBUG_MAXID; depends lib/data.h */
-
 /* Globals for this module start with db_ */
 static int db_mib[] = { CTL_DEBUG, 0, CTL_DEBUG_VALUE };
 static int db_v[SYMON_MAXDEBUGID];
-/* Prepare if module for first use */
+
 void
-init_debug(char *s)
+init_debug(struct stream *st)
 {
-    info("started module debug(%.200s)", s);
+    info("started module debug(%.200s)", st->arg);
 }
-/* Get debug statistics */
+
 int
-get_debug(char *symon_buf, int maxlen, char *s)
+get_debug(char *symon_buf, int maxlen, struct stream *st)
 {
     size_t len;
     int i;
@@ -73,7 +71,7 @@ get_debug(char *symon_buf, int maxlen, char *s)
 	sysctl(db_mib, sizeof(db_mib)/sizeof(int), &db_v[i], &len, NULL, 0);
     }
 
-    return snpack(symon_buf, maxlen, s, MT_DEBUG,
+    return snpack(symon_buf, maxlen, st->arg, MT_DEBUG,
 		  db_v[0], db_v[1], db_v[2], db_v[3], db_v[4], db_v[5], db_v[6],
 		  db_v[7], db_v[8], db_v[9], db_v[10], db_v[11], db_v[12], db_v[13],
 		  db_v[14], db_v[15], db_v[16], db_v[17], db_v[18], db_v[19]);
