@@ -1,4 +1,4 @@
-/* $Id: sm_mem.c,v 1.17 2005/02/25 15:10:10 dijkstra Exp $ */
+/* $Id: sm_mem.c,v 1.20 2005/10/18 19:58:11 dijkstra Exp $ */
 
 /*
  * Copyright (c) 2001-2004 Willem Dijkstra
@@ -34,8 +34,6 @@
  * Get current memory statistics in bytes; reports them back in symon_buf as
  *
  * real active : real total : free : [swap used : swap total]
- *
- * This code is not re-entrant.
  */
 
 #include <sys/param.h>
@@ -63,9 +61,9 @@ static size_t me_vmsize;
 static int me_pagesize;
 static int me_nswap;
 struct swapent *me_swdev = NULL;
-/* Prepare mem module for first use */
+
 void
-init_mem(char *s)
+init_mem(struct stream *st)
 {
     me_pagesize = sysconf(_SC_PAGESIZE);
     me_pageshift = 0;
@@ -80,22 +78,27 @@ init_mem(char *s)
     /* determine number of swap entries */
     me_nswap = swapctl(SWAP_NSWAP, 0, 0);
 
-    if (me_swdev)
+    if (me_swdev) {
 	xfree(me_swdev);
+    }
 
-    if (me_nswap != 0)
+    if (me_nswap != 0) {
 	me_swdev = xmalloc(me_nswap * sizeof(*me_swdev));
-    else
+    } else {
 	me_swdev = NULL;
+    }
 
-    if (me_swdev == NULL && me_nswap != 0)
+    if (me_swdev == NULL && me_nswap != 0) {
 	me_nswap = 0;
+    }
 
-    info("started module mem(%.200s)", s);
+    if (st != NULL) {
+	info("started module mem(%.200s)", st->arg);
+    }
 }
-/* Get memory statistics */
-int
-get_mem(char *symon_buf, int maxlen, char *s)
+
+void
+gets_mem()
 {
     int i, rnswap;
 
@@ -126,8 +129,12 @@ get_mem(char *symon_buf, int maxlen, char *s)
 	    }
 	}
     }
+}
 
-    return snpack(symon_buf, maxlen, s, MT_MEM,
+int
+get_mem(char *symon_buf, int maxlen, struct stream *st)
+{
+    return snpack(symon_buf, maxlen, st->arg, MT_MEM,
 		  me_stats[0], me_stats[1], me_stats[2],
 		  me_stats[3], me_stats[4]);
 }
