@@ -1,11 +1,13 @@
-/* $Id: sm_io.c,v 1.1 2004/08/07 12:21:36 dijkstra Exp $ */
+/* $Id: sm_io.c,v 1.2 2005/10/18 19:58:12 dijkstra Exp $ */
 
 #include <stdlib.h>
 
+#include "sylimits.h"
+#include "data.h"
 #include "error.h"
 
 void
-init_io(char *s)
+init_io(struct stream *st)
 {
     fatal("io module not available");
 }
@@ -15,7 +17,7 @@ gets_io()
     fatal("io module not available");
 }
 int
-get_io(char *symon_buf, int maxlen, char *s)
+get_io(char *symon_buf, int maxlen, struct stream *st)
 {
     fatal("io module not available");
 
