@@ -1,4 +1,4 @@
-/* $Id: symon.h,v 1.33 2005/03/20 16:17:22 dijkstra Exp $ */
+/* $Id: symon.h,v 1.35 2005/10/16 15:27:01 dijkstra Exp $ */
 
 /*
  * Copyright (c) 2001-2005 Willem Dijkstra
@@ -38,12 +38,6 @@
 
 #define SYMON_PID_FILE "/var/run/symon.pid"
 #define SYMON_DEFAULT_INTERVAL 5	/* measurement interval */
-#define SYMON_WARN_SENDERR 50	        /* warn every x errors */
-#define SYMON_MAX_DOBJECTS 10000	/* max dynamic allocation; local limit per
-					 * measurement module */
-#define SYMON_MAX_OBJSIZE (_POSIX2_LINE_MAX)
-#define SYMON_SENSORMASK 0xFF           /* sensors 0-255 are allowed */
-#define SYMON_MAXCPUS 4
 
 /* funcmap holds functions to be called for the individual monitors:
  *
@@ -57,9 +51,9 @@ struct funcmap {
     int type;
     int used;
     void (*privinit) ();
-    void (*init) (char *);
+    void (*init) (struct stream *);
     void (*gets) ();
-    int (*get) (char *, int, char *);
+    int (*get) (char *, int, struct stream *);
 };
 extern struct funcmap streamfunc[];
 
@@ -68,52 +62,60 @@ extern int symon_interval;
 /* prototypes */
 __BEGIN_DECLS
 /* sm_cpu.c */
-extern void init_cpu(char *);
+extern void init_cpu(struct stream *);
 extern void gets_cpu();
-extern int get_cpu(char *, int, char *);
+extern int get_cpu(char *, int, struct stream *);
 
 /* sm_mem.c */
-extern void init_mem(char *);
-extern int get_mem(char *, int, char *);
+extern void init_mem(struct stream *);
+extern void gets_mem();
+extern int get_mem(char *, int, struct stream *);
 
 /* sm_if.c */
-extern void init_if(char *);
+extern void init_if(struct stream *);
 extern void gets_if();
-extern int get_if(char *, int, char *);
+extern int get_if(char *, int, struct stream *);
 
 /* sm_io.c */
-extern void init_io(char *);
+extern void init_io(struct stream *);
 extern void gets_io();
-extern int get_io(char *, int, char *);
+extern int get_io(char *, int, struct stream *);
 
 /* sm_pf.c */
 extern void privinit_pf();
-extern void init_pf(char *);
-extern int get_pf(char *, int, char *);
+extern void init_pf(struct stream *);
+extern void gets_pf();
+extern int get_pf(char *, int, struct stream *);
 
 /* sm_pfq.c */
 extern void privinit_pfq();
-extern void init_pfq(char *);
+extern void init_pfq(struct stream *);
 extern void gets_pfq();
-extern int get_pfq(char *, int, char *);
+extern int get_pfq(char *, int, struct stream *);
 
 /* sm_mbuf.c */
-extern void init_mbuf(char *);
-extern int get_mbuf(char *, int, char *);
+extern void init_mbuf(struct stream *);
+extern int get_mbuf(char *, int, struct stream *);
 
 /* sm_debug.c */
-extern void init_debug(char *);
-extern int get_debug(char *, int, char *);
+extern void init_debug(struct stream *);
+extern int get_debug(char *, int, struct stream *);
 
 /* sm_proc.c */
-extern void init_proc(char *);
+extern void privinit_proc();
+extern void init_proc(struct stream *);
 extern void gets_proc();
-extern int get_proc(char *, int, char *);
+extern int get_proc(char *, int, struct stream *);
 
 /* sm_sensor.c */
 extern void privinit_sensor();
-extern void init_sensor(char *);
-extern int get_sensor(char *, int, char *);
+extern void init_sensor(struct stream *);
+extern int get_sensor(char *, int, struct stream *);
+
+/* sm_df.c */
+extern void init_df(struct stream *);
+extern void gets_df();
+extern int get_df(char *, int, struct stream *);
 __END_DECLS
 
 #endif				/* _SYMON_SYMON_H */
